NengoDL
=======

.. toctree::
    :maxdepth: 3

    introduction
    installation
    frontend
    resources
    backend

`Github <https://github.com/nengo/nengo_dl>`_ |
`PyPI <https://pypi.python.org/pypi/nengo_dl>`_